from geometry-inetsmol import Circle, Triangle
from geometry-inetsmol.factory import shape_from_args

def test_circle_area():
    assert round(Circle(1).area(), 5) == round(3.14159, 5)

def test_triangle_area():
    t = Triangle(3, 4, 5)
    assert round(t.area(), 2) == 6.0

def test_triangle_right():
    assert Triangle(3, 4, 5).is_right() is True
    assert Triangle(3, 4, 6).is_right() is False

def test_shape_factory_circle():
    s = shape_from_args(2)
    assert round(s.area(), 2) == round(3.14159 * 4, 2)

def test_shape_factory_triangle():
    s = shape_from_args(3, 4, 5)
    assert round(s.area(), 2) == 6.0



from geometry import Circle, Triangle, Shape

def shape_from_args(*args: float) -> Shape:
    if len(args) == 1:
        return Circle(args[0])
    elif len(args) == 3:
        return Triangle(*args)
    raise ValueError("Unsupported shape arguments")



from abc import ABC, abstractmethod
from math import pi, sqrt, isclose

class Shape(ABC):
    @abstractmethod
    def area(self) -> float:
        pass

class Circle(Shape):
    def __init__(self, radius: float):
        self.r = radius

    def area(self) -> float:
        return pi * self.r ** 2

class Triangle(Shape):
    def __init__(self, a: float, b: float, c: float):
        self.a, self.b, self.c = sorted([a, b, c])

    def area(self) -> float:
        p = (self.a + self.b + self.c) / 2
        return sqrt(p * (p - self.a) * (p - self.b) * (p - self.c))

    def is_right(self) -> bool:
        return isclose(self.a**2 + self.b**2, self.c**2)



from setuptools import setup, find_packages

setup(
    name="geometry-inetsmol",
    version="0.1.0",
    packages=find_packages(),
    install_requires=[],
    python_requires=">=3.7",
    author="iNetsmol",
    description="Вычисление площади круга и треугольника",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    license="MIT",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
    ],
)
